#include <esp_now.h>
#include <WiFi.h>

uint8_t broadcastAddress[] = {0x30, 0xAE, 0xA4, 0x8D, 0x85, 0x64};

const int pingPin = 13;
int inPin = 12;
int freq = 1000;
int channel = 0;
int resolution = 14;

typedef struct struct_message {
  int a ;
  int b;
  int c;
} struct_message;

struct_message Ultrasonic;

void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.print("\r\nLast Packet Send Status:\t");
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}
 
void setup() {
  Serial.begin(115200);
  ledcSetup(channel, freq, resolution);
  ledcAttachPin(23, channel);

  
  WiFi.mode(WIFI_STA);


  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }

  
  esp_now_peer_info_t peerInfo;
  memcpy(peerInfo.peer_addr, broadcastAddress, 6);
  peerInfo.channel = 0;  
  peerInfo.encrypt = false;
         
  if (esp_now_add_peer(&peerInfo) != ESP_OK){
    Serial.println("Failed to add peer");
    return;
  }
  esp_now_register_send_cb(OnDataSent);
}
 
void loop() {
  long duration, cm;
  pinMode(pingPin, OUTPUT);  
  digitalWrite(pingPin, LOW);  
  delayMicroseconds(2); 
  digitalWrite(pingPin, HIGH); 
  delayMicroseconds(5);
  digitalWrite(pingPin, LOW);
  pinMode(inPin, INPUT);
  
  duration = pulseIn(inPin, HIGH);
  cm = microsecondsToCentimeters(duration);

  
  if (cm <= 3) { 
    Ultrasonic.a = 100;
    Ultrasonic.b = 30;
    Ultrasonic.c = 1;
    Serial.println("Open");
    ledcWrite(channel, 900);

  }
  else{
    Serial.println("Close");
    ledcWrite(channel, 0);
  }
  

  esp_err_t result = esp_now_send(broadcastAddress, (uint8_t *) &Ultrasonic, sizeof(Ultrasonic));
   
  if (result == ESP_OK) {
    Serial.println("Sent with success");
  }
  else {
    Serial.println("Error sending the data");
  }
  delay(4000);
}

long microsecondsToCentimeters(long microseconds){
    return microseconds / 29 / 2;
}
